summaryrefslogtreecommitdiffstats
path: root/libkdchart
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:17 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:56:17 -0600
commit1f9d00360b9018301630ce062d7dda0c6583edfb (patch)
tree1013b917f9a8ad41ed928d62250e9bfe1ed91414 /libkdchart
parent252fce5a2a5384702fbcc1c9987284d7bd2e6943 (diff)
downloadkmymoney-1f9d00360b9018301630ce062d7dda0c6583edfb.tar.gz
kmymoney-1f9d00360b9018301630ce062d7dda0c6583edfb.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 252fce5a2a5384702fbcc1c9987284d7bd2e6943.
Diffstat (limited to 'libkdchart')
-rw-r--r--libkdchart/KDChart.cpp26
-rw-r--r--libkdchart/KDChartAreaPainter.cpp2
-rw-r--r--libkdchart/KDChartAxesPainter.cpp14
-rw-r--r--libkdchart/KDChartAxisParams.cpp2
-rw-r--r--libkdchart/KDChartAxisParams.h2
-rw-r--r--libkdchart/KDChartBWPainter.cpp4
-rw-r--r--libkdchart/KDChartBarPainter.cpp4
-rw-r--r--libkdchart/KDChartCustomBox.cpp2
-rw-r--r--libkdchart/KDChartCustomBox.h14
-rw-r--r--libkdchart/KDChartDataIntern.h4
-rw-r--r--libkdchart/KDChartEnums.h24
-rw-r--r--libkdchart/KDChartHiLoPainter.cpp2
-rw-r--r--libkdchart/KDChartLinesPainter.cpp2
-rw-r--r--libkdchart/KDChartObjectFactory.cpp72
-rw-r--r--libkdchart/KDChartPainter.cpp20
-rw-r--r--libkdchart/KDChartParams.cpp48
-rw-r--r--libkdchart/KDChartParams.h6
-rw-r--r--libkdchart/KDChartParams_io.cpp10
-rw-r--r--libkdchart/KDChartPiePainter.cpp4
-rw-r--r--libkdchart/KDChartPolarPainter.cpp10
-rw-r--r--libkdchart/KDChartPropertySet.h8
-rw-r--r--libkdchart/KDChartRingPainter.cpp4
-rw-r--r--libkdchart/KDChartTableBase.cpp2
-rw-r--r--libkdchart/KDChartTextPiece.cpp2
-rw-r--r--libkdchart/KDChartTextPiece.h2
-rw-r--r--libkdchart/KDChartWidget.cpp6
-rw-r--r--libkdchart/KDChartWrapperFactory.cpp8
-rw-r--r--libkdchart/KDDrawText.cpp2
-rw-r--r--libkdchart/KDDrawText.h4
-rw-r--r--libkdchart/KDFrame.cpp2
-rw-r--r--libkdchart/KDFrame.h2
-rw-r--r--libkdchart/KDFrameProfileSection.h2
-rw-r--r--libkdchart/KDXMLTools.h2
33 files changed, 159 insertions, 159 deletions
diff --git a/libkdchart/KDChart.cpp b/libkdchart/KDChart.cpp
index 4d8fd0c..415f013 100644
--- a/libkdchart/KDChart.cpp
+++ b/libkdchart/KDChart.cpp
@@ -302,7 +302,7 @@ void KDChart::paint( TQPainter* painter,
}
//qDebug("xxx" );
if( (params || data) && !setupGeometry( painter, params, data, drawRect ) ){
- qDebug("ERROR: KDChart::paint() could not calculate the chart geometry.");
+ qDebug("ERROR: KDChart::paint() could not calculate the chart tqgeometry.");
bOk = false;
}
}else{
@@ -388,7 +388,7 @@ void KDChart::initInterpreter( TQSInterpreter* interpreter )
void KDChart::initProject( TQSProject* project )
{
- project->createScript( TQString::fromLatin1( "KDCHART_Globals" ), globals() );
+ project->createScript( TQString::tqfromLatin1( "KDCHART_Globals" ), globals() );
privateInitInterpreter( project->interpreter() );
}
@@ -431,20 +431,20 @@ TQString KDChart::globals()
for( TQMapIterator<char*,double> it= intMap.begin(); it != intMap.end(); ++it ) {
// This is written this way to be efficient
- globals += TQString::fromLatin1( "const " );
+ globals += TQString::tqfromLatin1( "const " );
globals += it.key();
globals += " = ";
globals += TQString::number( it.data() );
globals += ";\n";
}
- globals += TQString::fromLatin1( "const KDCHART_AXIS_LABELS_AUTO_DATETIME_FORMAT=\"%1\";\n" )
- .arg( TQString::fromLatin1( KDCHART_AXIS_LABELS_AUTO_DATETIME_FORMAT ) );
- globals += TQString::fromLatin1( "const KDCHART_AXIS_LABELS_AUTO_LIMIT = 140319.64;\n" );
- globals += TQString::fromLatin1( "const KDCHART_DEFAULT_AXIS_GRID_COLOR = new Color(\"%1\");\n" )
- .arg(KDCHART_DEFAULT_AXIS_GRID_COLOR.name());
- globals += TQString::fromLatin1( "const KDCHART_DATA_VALUE_AUTO_COLOR = new Color(\"%1\");\n" )
- .arg( (KDCHART_DATA_VALUE_AUTO_COLOR)->name());
+ globals += TQString::tqfromLatin1( "const KDCHART_AXIS_LABELS_AUTO_DATETIME_FORMAT=\"%1\";\n" )
+ .tqarg( TQString::tqfromLatin1( KDCHART_AXIS_LABELS_AUTO_DATETIME_FORMAT ) );
+ globals += TQString::tqfromLatin1( "const KDCHART_AXIS_LABELS_AUTO_LIMIT = 140319.64;\n" );
+ globals += TQString::tqfromLatin1( "const KDCHART_DEFAULT_AXIS_GRID_COLOR = new Color(\"%1\");\n" )
+ .tqarg(KDCHART_DEFAULT_AXIS_GRID_COLOR.name());
+ globals += TQString::tqfromLatin1( "const KDCHART_DATA_VALUE_AUTO_COLOR = new Color(\"%1\");\n" )
+ .tqarg( (KDCHART_DATA_VALUE_AUTO_COLOR)->name());
TQMap<char*,TQColor> colorMap;
@@ -469,14 +469,14 @@ TQString KDChart::globals()
colorMap.insert( "TQt.darkYellow", TQt::darkYellow );
for( TQMapIterator<char*,TQColor> it2= colorMap.begin(); it2 != colorMap.end(); ++it2 ) {
// This is written this way to be efficient
- globals += TQString::fromLatin1( it2.key() );
- globals += TQString::fromLatin1( " = new Color( " );
+ globals += TQString::tqfromLatin1( it2.key() );
+ globals += TQString::tqfromLatin1( " = new Color( " );
globals += TQString::number( it2.data().red() );
globals += ',';
globals += TQString::number( it2.data().green() );
globals += ',';
globals += TQString::number( it2.data().blue() );
- globals += TQString::fromLatin1( " );\n" );
+ globals += TQString::tqfromLatin1( " );\n" );
}
//qDebug( "%s",globals.latin1() );
return globals;
diff --git a/libkdchart/KDChartAreaPainter.cpp b/libkdchart/KDChartAreaPainter.cpp
index 2fca8d6..6c47aee 100644
--- a/libkdchart/KDChartAreaPainter.cpp
+++ b/libkdchart/KDChartAreaPainter.cpp
@@ -43,7 +43,7 @@
KDChartLinesPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // geometry yet since we do not know the size of the painter.
+ // tqgeometry yet since we do not know the size of the painter.
}
diff --git a/libkdchart/KDChartAxesPainter.cpp b/libkdchart/KDChartAxesPainter.cpp
index ee9dc87..6124abe 100644
--- a/libkdchart/KDChartAxesPainter.cpp
+++ b/libkdchart/KDChartAxesPainter.cpp
@@ -65,7 +65,7 @@ int secondsSinceUTCStart( const TQDateTime& dt )
KDChartPainter( params )
{
// Intentionally left blank.
- // We cannot setup the geometry yet
+ // We cannot setup the tqgeometry yet
// since we do not know the size of the painter.
}
@@ -680,7 +680,7 @@ void KDChartAxesPainter::paintAxes( TQPainter* painter,
anchor.setY( p2.y() + static_cast < int > ( pYDelta * (iLabel - 0.5) ) );
// allow for shearing and/or scaling of the painter
- anchor = painter->worldMatrix().map( anchor );
+ anchor = painter->tqworldMatrix().map( anchor );
TQString text;
if( cv.isDateTime ){
@@ -1762,7 +1762,7 @@ void KDChartAxesPainter::paintAxes( TQPainter* painter,
KDDrawText::drawRotatedText(
painter,
nRotation,
- painter->worldMatrix().map(
+ painter->tqworldMatrix().map(
TQPoint( static_cast<int>( cv.pTextsX ),
static_cast<int>( cv.pTextsY ) ) ),
label,
@@ -2823,7 +2823,7 @@ void KDChartAxesPainter::calculateLabelTexts(
const double secHour = 60.0 * secMin;
const double secDay = 24.0 * secHour;
//
- // we temporarily disable week alignment until bug
+ // we temporarily disable week tqalignment until bug
// is fixed (1st week of year must not start in the
// preceeding year but rather be shown incompletely)
//
@@ -3661,7 +3661,7 @@ TQString KDChartAxesPainter::truncateBehindComma( const double nVal,
sVal.setNum( nVal, 'f', bUseAutoDigits ? nTrustedPrecision
: TQMIN(behindComma, nTrustedPrecision) );
//qDebug("nVal: %f sVal: "+sVal, nVal );
- //qDebug( TQString(" %1").arg(sVal));
+ //qDebug( TQString(" %1").tqarg(sVal));
if ( bUseAutoDigits ) {
int comma = sVal.find( '.' );
if ( -1 < comma ) {
@@ -3697,7 +3697,7 @@ TQString KDChartAxesPainter::truncateBehindComma( const double nVal,
}
}
}
- //qDebug( TQString(" - %1").arg(trueBehindComma));
+ //qDebug( TQString(" - %1").tqarg(trueBehindComma));
return sVal;
}
@@ -4424,7 +4424,7 @@ void KDChartAxesPainter::paintData( TQPainter* painter,
//ourClipRect.setLeft( ourClipRect.left() + 1 );
//ourClipRect.setRight( ourClipRect.right() - 1 );
- const TQWMatrix & world = painter->worldMatrix();
+ const TQWMatrix & world = painter->tqworldMatrix();
ourClipRect =
#if COMPAT_TQT_VERSION >= 0x030000
world.mapRect( ourClipRect );
diff --git a/libkdchart/KDChartAxisParams.cpp b/libkdchart/KDChartAxisParams.cpp
index b24892b..a6e337f 100644
--- a/libkdchart/KDChartAxisParams.cpp
+++ b/libkdchart/KDChartAxisParams.cpp
@@ -297,7 +297,7 @@ become wider or more narrow.
Also the graphical representation of the date will be comparable
since all your charts will use the same scale if you wish this.
-- Let the program calculate the chart layout based upon the kind
+- Let the program calculate the chart tqlayout based upon the kind
of and width of the labels to be drawn at the axes.
Also the program can calculate the labels for you and find the
boundary values for start and end of the scale automatically.
diff --git a/libkdchart/KDChartAxisParams.h b/libkdchart/KDChartAxisParams.h
index c2f9be9..b581970 100644
--- a/libkdchart/KDChartAxisParams.h
+++ b/libkdchart/KDChartAxisParams.h
@@ -33,7 +33,7 @@
#include <tqcolor.h>
#include <tqmap.h>
#include <tqobject.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqstringlist.h>
#include <tqdatetime.h>
#include <tqvariant.h>
diff --git a/libkdchart/KDChartBWPainter.cpp b/libkdchart/KDChartBWPainter.cpp
index 7fed752..9f6e5fb 100644
--- a/libkdchart/KDChartBWPainter.cpp
+++ b/libkdchart/KDChartBWPainter.cpp
@@ -55,7 +55,7 @@
KDChartAxesPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // geometry yet since we do not know the size of the painter.
+ // tqgeometry yet since we do not know the size of the painter.
}
@@ -291,7 +291,7 @@ void KDChartBWPainter::specificPaintData( TQPainter* painter,
const bool noBrush = TQt::NoBrush == params()->bWChartBrush().style();
- // Loop over the datasets, draw one box and whisker shape for each series.
+ // Loop over the datasets, draw one box and whisker tqshape for each series.
for ( uint dataset = chartDatasetStart;
dataset <= chartDatasetEnd;
++dataset ) {
diff --git a/libkdchart/KDChartBarPainter.cpp b/libkdchart/KDChartBarPainter.cpp
index 8bfe1a7..f8ae89d 100644
--- a/libkdchart/KDChartBarPainter.cpp
+++ b/libkdchart/KDChartBarPainter.cpp
@@ -48,7 +48,7 @@ KDChartBarPainter::KDChartBarPainter( KDChartParams* params ) :
KDChartAxesPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // geometry yet since we do not know the size of the painter.
+ // tqgeometry yet since we do not know the size of the painter.
}
@@ -226,7 +226,7 @@ void KDChartBarPainter::specificPaintData( TQPainter* painter,
? 0.0
: static_cast<int>( valueBlockGap ) * numValues;
- // Set some geometry values that apply to bar charts only
+ // Set some tqgeometry values that apply to bar charts only
double totalNumberOfBars = 0.0;
double spaceBetweenDatasets = 0.0;
switch ( params()->barChartSubType() ) {
diff --git a/libkdchart/KDChartCustomBox.cpp b/libkdchart/KDChartCustomBox.cpp
index 7066e88..9b4d785 100644
--- a/libkdchart/KDChartCustomBox.cpp
+++ b/libkdchart/KDChartCustomBox.cpp
@@ -28,7 +28,7 @@
**********************************************************************/
#include <tqpainter.h>
#include <tqregion.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqpoint.h>
#include <tqsimplerichtext.h>
#include <tqpaintdevicemetrics.h>
diff --git a/libkdchart/KDChartCustomBox.h b/libkdchart/KDChartCustomBox.h
index 2e1edf1..223920e 100644
--- a/libkdchart/KDChartCustomBox.h
+++ b/libkdchart/KDChartCustomBox.h
@@ -30,7 +30,7 @@
#define __KDCHARTCUSTOMBOX_H__
#include <tqobject.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqfont.h>
#include <tqdom.h>
#include "KDChartGlobal.h"
@@ -181,7 +181,7 @@ public:
\param deltaAlign The way how \c deltaX and \deltaY affect the position of the box.
Leave this parameter to its default value KDCHART_AlignAuto to have the delta values
used according to the box's main \c align settings, otherwise specify your own
- alignment settings: e.g. right means there will be a gap between the right side of
+ tqalignment settings: e.g. right means there will be a gap between the right side of
the box and its anchor point - if the main \c align parameter is set to right too
the anchor point will to be outside of the box / if \c align is set to left
(but the \c deltaAlign to right) the anchor point will be inside the box.
@@ -192,7 +192,7 @@ public:
\li \c TQt::AlignRight | TQt::AlignTop
\li \c TQt::AlignRight | TQt::AlignBottom
Using AlignVCenter or AlignHCenter or AlignCenter does not make sense here:
- center delta alignment will cause KDChart to ignore the respective delta
+ center delta tqalignment will cause KDChart to ignore the respective delta
settings: deltaX or deltaY or both will become ineffective.
\param deltaScaleGlobal If true the actual delta X and delta Y values will
be calculated by \c deltaX and \c deltaY based upon the size of the
@@ -297,7 +297,7 @@ public:
\param deltaAlign The way how \c deltaX and \deltaY affect the position of the box.
Leave this parameter to its default value KDCHART_AlignAuto to have the delta values
used according to the box's main \c align settings, otherwise specify your own
- alignment settings: e.g. TQt::AlignRight means the box will be moved to the left
+ tqalignment settings: e.g. TQt::AlignRight means the box will be moved to the left
(by the amount calculated using the \c deltaX value), so there will be a gap
between the right side of the box and its anchor point IF the main \c align flag
is set to TQt::AlignRight too, so the anchor point will to be outside of the
@@ -310,7 +310,7 @@ public:
\li \c TQt::AlignRight | TQt::AlignTop
\li \c TQt::AlignRight | TQt::AlignBottom
Using AlignVCenter or AlignHCenter or AlignCenter does not make sense here:
- center delta alignment will cause KDChart to ignore the respective delta
+ center delta tqalignment will cause KDChart to ignore the respective delta
settings: deltaX or deltaY or both will become ineffective.
\note Moving of the box due to \c deltaAlign settings is applied after
the box is rotated: e.g. this means a gap specified by \c deltaAlign = TQt::AlignTop
@@ -643,7 +643,7 @@ public slots: // PENDING(blackie) merge slots sections.
Set this to KDHART_KDCHART_AlignAuto to have the delta values
used according to the box's main \c align settings, otherwise specify your own
- alignment settings: e.g. right means there will be a gap between the right side of
+ tqalignment settings: e.g. right means there will be a gap between the right side of
the box and its anchor point - if the main \c align parameter is set to right too
the anchor point will to be outside of the box / if \c align is set to left
(but the \c deltaAlign to right) the anchor point will be inside the box.
@@ -654,7 +654,7 @@ public slots: // PENDING(blackie) merge slots sections.
\li \c TQt::AlignRight | TQt::AlignTop
\li \c TQt::AlignRight | TQt::AlignBottom
Using AlignVCenter or AlignHCenter or AlignCenter does not make sense here:
- center delta alignment will cause KDChart to ignore the respective delta
+ center delta tqalignment will cause KDChart to ignore the respective delta
settings: deltaX or deltaY or both will become ineffective.
\note Moving of the box due to \c deltaAlign settings is applied after
the box is rotated: e.g. this means a gap specified by \c deltaAlign = TQt::AlignTop
diff --git a/libkdchart/KDChartDataIntern.h b/libkdchart/KDChartDataIntern.h
index fe8cfc8..a1d6562 100644
--- a/libkdchart/KDChartDataIntern.h
+++ b/libkdchart/KDChartDataIntern.h
@@ -231,7 +231,7 @@ public:
}
}
// Note: We do *not* compare the _propSetID here since it contains
- // no values but is used to handle some layout information...
+ // no values but is used to handle some tqlayout information...
}
return bRet;
}
@@ -289,7 +289,7 @@ public:
/* NOOP */;
}
// Note: We do *not* copy the _propSetID here since it contains
- // no values but is used to handle some layout information...
+ // no values but is used to handle some tqlayout information...
}
}
diff --git a/libkdchart/KDChartEnums.h b/libkdchart/KDChartEnums.h
index 71373d5..82956e8 100644
--- a/libkdchart/KDChartEnums.h
+++ b/libkdchart/KDChartEnums.h
@@ -53,10 +53,10 @@ class KDCHART_EXPORT KDChartEnums :public TQObject
public:
/**
- Text layout policy: what to do if text that is to be drawn would
+ Text tqlayout policy: what to do if text that is to be drawn would
cover neighboring text or neighboring areas.
- \li \c LayoutJustOverwrite Just ignore the layout collision and write the text nevertheless.
+ \li \c LayoutJustOverwrite Just ignore the tqlayout collision and write the text nevertheless.
\li \c LayoutPolicyRotate Try counter-clockwise rotation to make the text fit into the space.
\li \c LayoutPolicyShiftVertically Shift the text baseline upwards (or downwards, resp.) and draw a connector line between the text and its anchor.
\li \c LayoutPolicyShiftHorizontally Shift the text baseline to the left (or to the right, resp.) and draw a connector line between the text and its anchor.
@@ -71,11 +71,11 @@ public:
LayoutPolicyShrinkFontSize };
/**
- Converts the specified text layout policy enum to a
+ Converts the specified text tqlayout policy enum to a
string representation.
- \param type the text layout policy to convert
- \return the string representation of the text layout policy enum
+ \param type the text tqlayout policy to convert
+ \return the string representation of the text tqlayout policy enum
*/
static TQString layoutPolicyToString( TextLayoutPolicy type ) {
switch( type ) {
@@ -90,7 +90,7 @@ public:
case LayoutPolicyShrinkFontSize:
return "ShrinkFontSize";
default: // should not happen
- qDebug( "Unknown text layout policy" );
+ qDebug( "Unknown text tqlayout policy" );
return "JustOverwrite";
}
}
@@ -150,10 +150,10 @@ public:
/**
- Converts the specified string to a text layout policy enum value.
+ Converts the specified string to a text tqlayout policy enum value.
\param string the string to convert
- \return the text layout policy enum value
+ \return the text tqlayout policy enum value
*/
static TextLayoutPolicy stringToLayoutPolicy( const TQString& string ) {
if( string == "JustOverwrite" )
@@ -240,7 +240,7 @@ public:
\image html "../refman_images/positions.png"
\image latex "../refman_images/positions.png" "the PositionFlag enum" width=4in
- \note The position and alignment of content to be printed at (or
+ \note The position and tqalignment of content to be printed at (or
inside of, resp.) an area or a point -- like for printing data value texts next
to their graphical representations (which might be a bar, line, pie slice,...) --
is specified by two parameters: a \c PositionFlag and a uint holding a combination of \c TQt::AlignmentFlags.
@@ -249,10 +249,10 @@ public:
The position of content and the way it is aligned to this
position is shown in the following drawing, note that annotation #2 and annotation #3
- share the same PositionFlag but have different alignment flags set:
+ share the same PositionFlag but have different tqalignment flags set:
- \image html "../refman_images/alignment.png"
- \image latex "../refman_images/alignment.png" "positioning and aligning" width=4in
+ \image html "../refman_images/tqalignment.png"
+ \image latex "../refman_images/tqalignment.png" "positioning and aligning" width=4in
\sa KDChartParams::setPrintDataValues
*/
diff --git a/libkdchart/KDChartHiLoPainter.cpp b/libkdchart/KDChartHiLoPainter.cpp
index d8f766c..bb8b2e3 100644
--- a/libkdchart/KDChartHiLoPainter.cpp
+++ b/libkdchart/KDChartHiLoPainter.cpp
@@ -49,7 +49,7 @@
KDChartAxesPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // geometry yet since we do not know the size of the painter.
+ // tqgeometry yet since we do not know the size of the painter.
}
diff --git a/libkdchart/KDChartLinesPainter.cpp b/libkdchart/KDChartLinesPainter.cpp
index 9f0995e..a7e0109 100644
--- a/libkdchart/KDChartLinesPainter.cpp
+++ b/libkdchart/KDChartLinesPainter.cpp
@@ -56,7 +56,7 @@ KDChartLinesPainter::KDChartLinesPainter( KDChartParams* params ) :
KDChartAxesPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // geometry yet since we do not know the size of the painter.
+ // tqgeometry yet since we do not know the size of the painter.
}
diff --git a/libkdchart/KDChartObjectFactory.cpp b/libkdchart/KDChartObjectFactory.cpp
index a53f84c..b1dac73 100644
--- a/libkdchart/KDChartObjectFactory.cpp
+++ b/libkdchart/KDChartObjectFactory.cpp
@@ -15,42 +15,42 @@
// PENDING(blackie) Clean up code in this file, so it uses the correct getter methods like getBool.
KDChartObjectFactory::KDChartObjectFactory()
{
- registerClass( TQString::fromLatin1( "KDChartWidget" ) );
- registerClass( TQString::fromLatin1( "KDChartParams" ), new KDChartParams );
- registerClass( TQString::fromLatin1( "KDChartTableData" ) );
- registerClass( TQString::fromLatin1( "KDChartAxisParams" ), new KDChartAxisParams );
- registerClass( TQString::fromLatin1( "KDChartEnums" ), 0, new KDChartEnums );
- registerClass( TQString::fromLatin1( "KDChartTextPiece" ) );
- registerClass( TQString::fromLatin1( "KDChartCustomBox" ), new KDChartCustomBox );
- registerClass( TQString::fromLatin1( "KDChartPropertySet" ), new KDChartPropertySet );
- registerClass( TQString::fromLatin1( "KDFrame" ), TQString(), new KDFrame );
-
- registerClass( TQString::fromLatin1( "TQt" ), TQString(), new TQtFactory() );
- registerClass( TQString::fromLatin1( "TQFont" ), TQString(), new TQFontFactory );
+ registerClass( TQString::tqfromLatin1( "KDChartWidget" ) );
+ registerClass( TQString::tqfromLatin1( "KDChartParams" ), new KDChartParams );
+ registerClass( TQString::tqfromLatin1( "KDChartTableData" ) );
+ registerClass( TQString::tqfromLatin1( "KDChartAxisParams" ), new KDChartAxisParams );
+ registerClass( TQString::tqfromLatin1( "KDChartEnums" ), 0, new KDChartEnums );
+ registerClass( TQString::tqfromLatin1( "KDChartTextPiece" ) );
+ registerClass( TQString::tqfromLatin1( "KDChartCustomBox" ), new KDChartCustomBox );
+ registerClass( TQString::tqfromLatin1( "KDChartPropertySet" ), new KDChartPropertySet );
+ registerClass( TQString::tqfromLatin1( "KDFrame" ), TQString(), new KDFrame );
+
+ registerClass( TQString::tqfromLatin1( "TQt" ), TQString(), new TQtFactory() );
+ registerClass( TQString::tqfromLatin1( "TQFont" ), TQString(), new TQFontFactory );
}
TQObject* KDChartObjectFactory::create( const TQString& className, const TQSArgumentList& args, TQObject* /*context*/ )
{
- if ( className == TQString::fromLatin1( "KDChartWidget" ) )
+ if ( className == TQString::tqfromLatin1( "KDChartWidget" ) )
return createKDChartWidget( args );
- if ( className == TQString::fromLatin1("KDChartParams") )
+ if ( className == TQString::tqfromLatin1("KDChartParams") )
return new KDChartParams();
- else if ( className == TQString::fromLatin1("KDChartTableData") )
+ else if ( className == TQString::tqfromLatin1("KDChartTableData") )
return createKDChartTableData( args );
- else if ( className == TQString::fromLatin1("KDChartAxisParams") )
+ else if ( className == TQString::tqfromLatin1("KDChartAxisParams") )
return new KDChartAxisParams();
- else if ( className == TQString::fromLatin1( "KDChartTextPiece" ) )
+ else if ( className == TQString::tqfromLatin1( "KDChartTextPiece" ) )
return createKDChartTextPiece( args );
- else if ( className == TQString::fromLatin1( "KDChartCustomBox" ) )
+ else if ( className == TQString::tqfromLatin1( "KDChartCustomBox" ) )
return createKDChartCustomBox( args );
- else if ( className == TQString::fromLatin1( "KDChartPropertySet" ) )
+ else if ( className == TQString::tqfromLatin1( "KDChartPropertySet" ) )
return createKDChartPropertySet( args );
else
@@ -98,7 +98,7 @@ TQObject* KDChartObjectFactory::createKDChartTextPiece( const TQSArgumentList& a
TQString str;
if ( !getString( args, 1, &str, "KDChartTextPiece" ) ) return 0;
- if ( !checkIsTQtVariant( args, 2, TQVariant::Font, TQString::fromLatin1( "TQFont" ), "KDChartTextPiece" ) ) return 0;
+ if ( !checkIsTQtVariant( args, 2, TQVariant::Font, TQString::tqfromLatin1( "TQFont" ), "KDChartTextPiece" ) ) return 0;
TQFont font = args[1].variant().toFont();
return new KDChartTextPiece( str, font );
@@ -145,13 +145,13 @@ TQObject* KDChartObjectFactory::createKDChartCustomBox( const TQSArgumentList& a
TQColor color = TQt::black;
if ( args.count() >= 9 ) {
- if ( !checkIsTQtVariant( args, 9, TQVariant::Color, TQString::fromLatin1( "TQColor" ), "KDChartCustomBox" ) ) return 0;
+ if ( !checkIsTQtVariant( args, 9, TQVariant::Color, TQString::tqfromLatin1( "TQColor" ), "KDChartCustomBox" ) ) return 0;
color = args[8].variant().toColor();
}
TQBrush paper = TQt::NoBrush;
if ( args.count() >= 10 ) {
- if ( !checkIsTQtVariant( args, 10, TQVariant::Brush, TQString::fromLatin1( "TQBrush" ), "KDChartCustomBox" ) ) return 0;
+ if ( !checkIsTQtVariant( args, 10, TQVariant::Brush, TQString::tqfromLatin1( "TQBrush" ), "KDChartCustomBox" ) ) return 0;
paper = args[9].variant().toBrush();
}
@@ -235,13 +235,13 @@ TQObject* KDChartObjectFactory::createKDChartCustomBox( const TQSArgumentList& a
TQColor color = TQt::black;
if ( args.count() >= 8 ) {
- if ( !checkIsTQtVariant( args, 8, TQVariant::Color, TQString::fromLatin1( "TQColor" ), "KDChartCustomBox" ) ) return 0;
+ if ( !checkIsTQtVariant( args, 8, TQVariant::Color, TQString::tqfromLatin1( "TQColor" ), "KDChartCustomBox" ) ) return 0;
color = args[7].variant().toColor();
}
TQBrush paper = TQt::NoBrush;
if ( args.count() >= 9 ) {
- if ( !checkIsTQtVariant( args, 9, TQVariant::Brush, TQString::fromLatin1( "TQBrush" ), "KDChartCustomBox" ) ) return 0;
+ if ( !checkIsTQtVariant( args, 9, TQVariant::Brush, TQString::tqfromLatin1( "TQBrush" ), "KDChartCustomBox" ) ) return 0;
paper = args[8].variant().toBrush();
}
@@ -318,7 +318,7 @@ TQObject* KDChartObjectFactory::createKDChartPropertySet(const TQSArgumentList&
if ( !getNumber( args, 4,&idLineColor, "KDChartPropertySet" ) ) return 0;
- if ( !checkIsTQtVariant( args, 5, TQVariant::Color, TQString::fromLatin1( "TQColor" ), "KDChartPropertySet" ) ) return 0;
+ if ( !checkIsTQtVariant( args, 5, TQVariant::Color, TQString::tqfromLatin1( "TQColor" ), "KDChartPropertySet" ) ) return 0;
TQColor lineColor = args[4].variant().toColor();
int idLineStyle;
@@ -362,7 +362,7 @@ TQObject* KDChartObjectFactory::createKDChartPropertySet(const TQSArgumentList&
int idExtraLinesColor;
if ( !getNumber( args, 18,&idExtraLinesColor, "KDChartPropertySet" ) ) return 0;
- if ( !checkIsTQtVariant( args, 19, TQVariant::Color, TQString::fromLatin1( "TQColor" ), "KDChartPropertySet" ) ) return 0;
+ if ( !checkIsTQtVariant( args, 19, TQVariant::Color, TQString::tqfromLatin1( "TQColor" ), "KDChartPropertySet" ) ) return 0;
TQColor extraLinesColor = args[18].variant().toColor();
int idExtraLinesStyle;
@@ -380,13 +380,13 @@ TQObject* KDChartObjectFactory::createKDChartPropertySet(const TQSArgumentList&
int idExtraMarkersSize;
if ( !getNumber( args, 24,&idExtraMarkersSize, "KDChartPropertySet" ) ) return 0;
- if ( !checkIsTQtVariant( args, 25, TQVariant::Size, TQString::fromLatin1( "TQSize" ), "KDChartPropertySet" ) ) return 0;
+ if ( !checkIsTQtVariant( args, 25, TQVariant::Size, TQString::tqfromLatin1( "TQSize" ), "KDChartPropertySet" ) ) return 0;
TQSize extraMarkersSize = args[24].variant().toSize();
int idExtraMarkersColor;
if ( !getNumber( args, 26,&idExtraMarkersColor, "KDChartPropertySet" ) ) return 0;
- if ( !checkIsTQtVariant( args, 27, TQVariant::Color, TQString::fromLatin1( "TQColor" ), "KDChartPropertySet" ) ) return 0;
+ if ( !checkIsTQtVariant( args, 27, TQVariant::Color, TQString::tqfromLatin1( "TQColor" ), "KDChartPropertySet" ) ) return 0;
TQColor extraMarkersColor = args[26].variant().toColor();
int idExtraMarkersStyle;
@@ -404,7 +404,7 @@ TQObject* KDChartObjectFactory::createKDChartPropertySet(const TQSArgumentList&
int idBarColor;
if ( !getNumber( args, 32,&idBarColor, "KDChartPropertySet" ) ) return 0;
- if ( !checkIsTQtVariant( args, 33, TQVariant::Color, TQString::fromLatin1( "TQColor" ), "KDChartPropertySet" ) ) return 0;
+ if ( !checkIsTQtVariant( args, 33, TQVariant::Color, TQString::tqfromLatin1( "TQColor" ), "KDChartPropertySet" ) ) return 0;
TQColor barColor = args[32].variant().toColor();
KDChartPropertySet* set = new KDChartPropertySet;
@@ -438,11 +438,11 @@ bool KDChartObjectFactory::isNumber( const TQVariant& v )
bool KDChartObjectFactory::checkArgCount( const TQString& className, int count, int min, int max )
{
if ( count < min ) {
- throwError( TQObject::tr( "Too few arguments when creating %1 object." ).arg( className ) );
+ throwError( TQObject::tr( "Too few arguments when creating %1 object." ).tqarg( className ) );
return false;
}
if ( count > max ) {
- throwError( TQObject::tr( "Too many arguments when creating %1 object." ).arg( className ) );
+ throwError( TQObject::tr( "Too many arguments when creating %1 object." ).tqarg( className ) );
return false;
}
return true;
@@ -453,7 +453,7 @@ bool KDChartObjectFactory::checkArgsIsTQtClass( const TQSArgumentList& args, int
{
const TQSArgument& arg = args[index-1];
if ( arg.type() != TQSArgument::TQObjectPtr || !arg.qobject()->inherits( expected ) ) {
- throwError( TQObject::tr( "Invalid type for argument no %1 to %2, must be a %3" ).arg(index).arg(constructing).arg(expected) );
+ throwError( TQObject::tr( "Invalid type for argument no %1 to %2, must be a %3" ).tqarg(index).tqarg(constructing).tqarg(expected) );
return false;
}
return true;
@@ -464,7 +464,7 @@ bool KDChartObjectFactory::getString( const TQSArgumentList& args, int index, TQ
{
const TQSArgument& arg = args[index-1];
if ( arg.type() != TQSArgument::Variant || arg.variant().type() != TQVariant::String ) {
- throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a string" ).arg(index).arg(constructing) );
+ throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a string" ).tqarg(index).tqarg(constructing) );
return false;
}
else {
@@ -477,7 +477,7 @@ bool KDChartObjectFactory::getNumber( const TQSArgumentList& args, int index, do
{
const TQSArgument& arg = args[index-1];
if ( arg.type() != TQSArgument::Variant || !isNumber(arg.variant()) ) {
- throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a number" ).arg(index).arg( constructing ) );
+ throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a number" ).tqarg(index).tqarg( constructing ) );
return false;
}
else {
@@ -508,7 +508,7 @@ bool KDChartObjectFactory::getBool( const TQSArgumentList& args, int index, bool
{
const TQSArgument& arg = args[index-1];
if ( arg.type() != TQSArgument::Variant || arg.variant().type() != TQVariant::Bool ) {
- throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a boolean" ).arg(index).arg( constructing ) );
+ throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a boolean" ).tqarg(index).tqarg( constructing ) );
return false;
}
else {
@@ -521,7 +521,7 @@ bool KDChartObjectFactory::checkIsTQtVariant( const TQSArgumentList& args, int i
{
const TQSArgument& arg = args[index-1];
if ( arg.type() != TQSArgument::Variant || arg.variant().type() != expected ) {
- throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a %3").arg(index).arg(constructing).arg(variantName) );
+ throwError( TQObject::tr( "Invalid type for argument %1 to %2, must be a %3").tqarg(index).tqarg(constructing).tqarg(variantName) );
return false;
}
else
diff --git a/libkdchart/KDChartParams.h b/libkdchart/KDChartParams.h
index 2e054d8..1672269 100644
--- a/libkdchart/KDChartParams.h
+++ b/libkdchart/KDChartParams.h
@@ -37,7 +37,7 @@
#include <tqdict.h>
#include <tqintdict.h>
#include <tqobject.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqsimplerichtext.h>
#include <tqdom.h>
#include <limits.h>
@@ -393,7 +393,7 @@ public slots:
bool addFrameHeightToLayout = true )
{
_areaDict.setAutoDelete( TRUE );
- _areaDict.replace( TQString( "%1/-----/-----/-----" ).arg( area, 5 ),
+ _areaDict.replace( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ),
new KDChartFrameSettings(0,0,0,
frame,
outerGapX,
@@ -436,7 +436,7 @@ public slots:
shadowWidth,
sunPos );
- _areaDict.replace( TQString( "%1/-----/-----/-----" ).arg( area, 5 ),
+ _areaDict.replace( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ),
new KDChartFrameSettings( 0,0,0, frame,
outerGapX,
outerGapY,
diff --git a/libkdchart/KDChartParams_io.cpp b/libkdchart/KDChartParams_io.cpp
index 86f37d6..4f17e65 100644
--- a/libkdchart/KDChartParams_io.cpp
+++ b/libkdchart/KDChartParams_io.cpp
@@ -2194,12 +2194,12 @@ bool KDChartParams::loadXML( const TQDomDocument& doc )
TQString str;
if(areaId == KDChartEnums::AreaChartDataRegion)
str = TQString( "%1/%2/%3/%4" )
- .arg( areaId, 5 )
- .arg( frameSettings->dataRow(), 5 )
- .arg( frameSettings->dataCol(), 5 )
- .arg( 0, 5 );//frameSettings->data3rd(), 5 );
+ .tqarg( areaId, 5 )
+ .tqarg( frameSettings->dataRow(), 5 )
+ .tqarg( frameSettings->dataCol(), 5 )
+ .tqarg( 0, 5 );//frameSettings->data3rd(), 5 );
else
- str = TQString( "%1/-----/-----/-----" ).arg( areaId, 5 );
+ str = TQString( "%1/-----/-----/-----" ).tqarg( areaId, 5 );
_areaDict.replace( str, frameSettings );
}
}
diff --git a/libkdchart/KDChartPiePainter.cpp b/libkdchart/KDChartPiePainter.cpp
index a8e126c..ada03b4 100644
--- a/libkdchart/KDChartPiePainter.cpp
+++ b/libkdchart/KDChartPiePainter.cpp
@@ -55,7 +55,7 @@
KDChartPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // geometry yet since we do not know the size of the painter.
+ // tqgeometry yet since we do not know the size of the painter.
}
@@ -89,7 +89,7 @@ void KDChartPiePainter::paintData( TQPainter* painter,
TQRect ourClipRect( _dataRect );
ourClipRect.addCoords( -1,-1,1,1 );
- const TQWMatrix & world = painter->worldMatrix();
+ const TQWMatrix & world = painter->tqworldMatrix();
ourClipRect =
#if COMPAT_TQT_VERSION >= 0x030000
world.mapRect( ourClipRect );
diff --git a/libkdchart/KDChartPolarPainter.cpp b/libkdchart/KDChartPolarPainter.cpp
index 99cee95..23430db 100644
--- a/libkdchart/KDChartPolarPainter.cpp
+++ b/libkdchart/KDChartPolarPainter.cpp
@@ -50,7 +50,7 @@ KDChartPolarPainter::KDChartPolarPainter( KDChartParams* params ) :
KDChartPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // geometry yet since we do not know the size of the painter.
+ // tqgeometry yet since we do not know the size of the painter.
}
@@ -89,7 +89,7 @@ void KDChartPolarPainter::paintData( TQPainter* painter,
// PENDING(khz) adjust the clip rect if neccessary...
//
- const TQWMatrix & world = painter->worldMatrix();
+ const TQWMatrix & world = painter->tqworldMatrix();
ourClipRect =
#if COMPAT_TQT_VERSION >= 0x030000
world.mapRect( ourClipRect );
@@ -515,7 +515,7 @@ void KDChartPolarPainter::paintData( TQPainter* painter,
pt2 = center + polarToXY( r2, currentAngle );
pt3 = center + polarToXY( r3, currentAngle );
- //pt3 = painter->worldMatrix().map( pt3 );
+ //pt3 = painter->tqworldMatrix().map( pt3 );
if( paraSagittal.axisShowGrid() ) {
painter->setPen( TQPen( paraSagittal.axisGridColor(),
@@ -538,7 +538,7 @@ void KDChartPolarPainter::paintData( TQPainter* painter,
KDDrawText::drawRotatedText( painter,
currentAngle+90,
- painter->worldMatrix().map(pt3),
+ painter->tqworldMatrix().map(pt3),
label,
0,
TQt::AlignCenter );
@@ -673,7 +673,7 @@ void KDChartPolarPainter::paintCircularAxisLabel( TQPainter* painter,
KDDrawText::drawRotatedText(
painter,
rotate ? txtAngle - 90 : 0,
- painter->worldMatrix().map(center - polarToXY( static_cast<int>( currentRadiusPPU ), txtAngle )),
+ painter->tqworldMatrix().map(center - polarToXY( static_cast<int>( currentRadiusPPU ), txtAngle )),
txt,
0,
step
diff --git a/libkdchart/KDChartPropertySet.h b/libkdchart/KDChartPropertySet.h
index bc61814..cdd64f7 100644
--- a/libkdchart/KDChartPropertySet.h
+++ b/libkdchart/KDChartPropertySet.h
@@ -34,7 +34,7 @@
#include <kdchart_export.h>
#include <tqdom.h>
#include <tqcolor.h>
-#include <brush.h>
+#include <tqbrush.h>
/**
\file KDChartPropertySet.h
@@ -721,14 +721,14 @@ public slots:
}
/**
- Specify the ID of the property set specifying the alignment of the
+ Specify the ID of the property set specifying the tqalignment of the
Marker to be displayed for this data value
<b>or</b> specifying this flag directly.
\note This function should be used for Line Charts only, otherwise
the settings specified here will be ignored.
- \param idMarkerAlign ID of the property set specifying the alignment
+ \param idMarkerAlign ID of the property set specifying the tqalignment
of the Marker to be shown.
Use special value KDChartPropertySet::UndefinedID
to specify neither another property set's ID
@@ -737,7 +737,7 @@ public slots:
if you do NOT want to inherit another property set's
settings but want to specify the flag by using
the following parameter.
- \param markerAlign The alignment of the marker to be shown.
+ \param markerAlign The tqalignment of the marker to be shown.
This parameter is stored but ignored if the previous parameter
is not set to KDChartPropertySet::OwnID.
diff --git a/libkdchart/KDChartRingPainter.cpp b/libkdchart/KDChartRingPainter.cpp
index ba1e6fe..9740fa5 100644
--- a/libkdchart/KDChartRingPainter.cpp
+++ b/libkdchart/KDChartRingPainter.cpp
@@ -53,7 +53,7 @@
KDChartPainter( params )
{
// This constructor intentionally left blank so far; we cannot setup the
- // geometry yet since we do not know the size of the painter.
+ // tqgeometry yet since we do not know the size of the painter.
}
@@ -84,7 +84,7 @@ void KDChartRingPainter::paintData( TQPainter* painter,
TQRect ourClipRect( _dataRect );
- const TQWMatrix & world = painter->worldMatrix();
+ const TQWMatrix & world = painter->tqworldMatrix();
ourClipRect =
#if COMPAT_TQT_VERSION >= 0x030000
world.mapRect( ourClipRect );
diff --git a/libkdchart/KDChartTableBase.cpp b/libkdchart/KDChartTableBase.cpp
index fcec2c5..1ebfa9f 100644
--- a/libkdchart/KDChartTableBase.cpp
+++ b/libkdchart/KDChartTableBase.cpp
@@ -74,7 +74,7 @@
future absicssa axis value:
\verbatim
- const TQDateTime currentTime( TQDateTime::currentDateTime() );
+ const TQDateTime currentTime( TQDateTime::tqcurrentDateTime() );
for( int iCell = 0; iCell < usedValues; ++iCell ){
KDChartData& cell = myData.cell( 0, iCell );
// assign special property set ID if X value is in the future
diff --git a/libkdchart/KDChartTextPiece.cpp b/libkdchart/KDChartTextPiece.cpp
index e986c85..b95165f 100644
--- a/libkdchart/KDChartTextPiece.cpp
+++ b/libkdchart/KDChartTextPiece.cpp
@@ -28,7 +28,7 @@
**********************************************************************/
#include "KDChartTextPiece.h"
-#include <stylesheet.h>
+#include <tqstylesheet.h>
#include <tqsimplerichtext.h>
#include <tqfontmetrics.h>
#include <tqpainter.h>
diff --git a/libkdchart/KDChartTextPiece.h b/libkdchart/KDChartTextPiece.h
index ab1916b..adb176b 100644
--- a/libkdchart/KDChartTextPiece.h
+++ b/libkdchart/KDChartTextPiece.h
@@ -32,7 +32,7 @@
#include <tqstring.h>
#include <tqfont.h>
#include <tqregion.h>
-#include <palette.h>
+#include <tqpalette.h>
#include <tqobject.h>
#include <kdchart_export.h>
diff --git a/libkdchart/KDChartWidget.cpp b/libkdchart/KDChartWidget.cpp
index 8217abf..d530ea1 100644
--- a/libkdchart/KDChartWidget.cpp
+++ b/libkdchart/KDChartWidget.cpp
@@ -244,8 +244,8 @@ void KDChartWidget::resizeEvent( TQResizeEvent* /*event*/ )
display process, so this is turned off by default.
If active data reporting is turned on when the widget is already
- shown, data will be reported after the next repaint(). Call
- repaint() explicitly if necessary.
+ shown, data will be reported after the next tqrepaint(). Call
+ tqrepaint() explicitly if necessary.
Active data is currently supported for bar, pie, and line charts
(the latter only with markers, as trying to hit the line would be
@@ -281,7 +281,7 @@ bool KDChartWidget::isActiveData() const
needs to be kept around. However, in most cases, it is worth
spending the extra memory. Double-buffering is on by
default. Turning double-buffering on or off does not trigger a
- repaint.
+ tqrepaint.
\param doublebuffered if true, turns double-buffering on, if false,
turns double-buffering off
diff --git a/libkdchart/KDChartWrapperFactory.cpp b/libkdchart/KDChartWrapperFactory.cpp
index b42c037..2ff08f1 100644
--- a/libkdchart/KDChartWrapperFactory.cpp
+++ b/libkdchart/KDChartWrapperFactory.cpp
@@ -17,16 +17,16 @@ KDChartWrapperFactory::KDChartWrapperFactory()
TQObject* KDChartWrapperFactory::create( const TQString& className, void* ptr )
{
- if ( className == TQString::fromLatin1( "KDChartParams" ) )
+ if ( className == TQString::tqfromLatin1( "KDChartParams" ) )
return new KDChartParamsWrapper( static_cast<KDChartParams*>( ptr ) );
- if ( className == TQString::fromLatin1( "KDChartVectorTableData" ) )
+ if ( className == TQString::tqfromLatin1( "KDChartVectorTableData" ) )
return new KDChartTableDataWrapper( static_cast<KDChartTableData*>( ptr ) );
- if ( className == TQString::fromLatin1( "KDChartCustomBox" ) )
+ if ( className == TQString::tqfromLatin1( "KDChartCustomBox" ) )
return new KDChartCustomBoxWrapper( static_cast<KDChartCustomBox*>( ptr ) );
- if ( className == TQString::fromLatin1( "KDChartAxisParams" ) )
+ if ( className == TQString::tqfromLatin1( "KDChartAxisParams" ) )
return new KDChartAxisParamsWrapper( static_cast<KDChartAxisParams*>( ptr ) );
return 0;
diff --git a/libkdchart/KDDrawText.cpp b/libkdchart/KDDrawText.cpp
index c098513..70283da 100644
--- a/libkdchart/KDDrawText.cpp
+++ b/libkdchart/KDDrawText.cpp
@@ -408,7 +408,7 @@ void KDDrawText::drawRotatedTxt( TQPainter* painter,
painter->drawLine( x+pBotRight.x(), y+pBotRight.y()-3, x+pBotRight.x(), y+pBotRight.y()+3 );
*/
- // The horizontal and vertical alignment together define one of
+ // The horizontal and vertical tqalignment together define one of
// NINE possible points: this point must be moved on the anchor.
int hAlign = align & ( TQt::AlignLeft | TQt::AlignRight | TQt::AlignHCenter );
int vAlign = align & ( TQt::AlignTop | TQt::AlignBottom | TQt::AlignVCenter );
diff --git a/libkdchart/KDDrawText.h b/libkdchart/KDDrawText.h
index 7842e9b..5fb9dbf 100644
--- a/libkdchart/KDDrawText.h
+++ b/libkdchart/KDDrawText.h
@@ -53,7 +53,7 @@ class KDDrawText
const TQString& text,
const TQFont* font = 0,
int align = TQt::AlignLeft | TQt::AlignTop,
- // useful for debugging of your layout:
+ // useful for debugging of your tqlayout:
bool showAnchor = false,
const TQFontMetrics* fontMet = 0,
bool noFirstrotate = false,
@@ -81,7 +81,7 @@ class KDDrawText
const TQString& text,
const TQFont* font = 0,
int align = TQt::AlignLeft | TQt::AlignTop,
- // usefull for debugging of your layout:
+ // usefull for debugging of your tqlayout:
bool showAnchor = false,
// speed-up parameters
// used internally by drawCircleText()
diff --git a/libkdchart/KDFrame.cpp b/libkdchart/KDFrame.cpp
index c760032..3904bf1 100644
--- a/libkdchart/KDFrame.cpp
+++ b/libkdchart/KDFrame.cpp
@@ -28,7 +28,7 @@
**********************************************************************/
#include <tqpainter.h>
-#include <brush.h>
+#include <tqbrush.h>
#include <KDFrame.h>
#include <KDFrameProfileSection.h>
diff --git a/libkdchart/KDFrame.h b/libkdchart/KDFrame.h
index e3bd6a1..78de8ff 100644
--- a/libkdchart/KDFrame.h
+++ b/libkdchart/KDFrame.h
@@ -36,7 +36,7 @@
#include <tqpen.h>
#include <tqmap.h>
#include <tqobject.h>
-#include <textstream.h>
+#include <tqtextstream.h>
#include <tqdom.h>
#include <KDFrameProfileSection.h>
diff --git a/libkdchart/KDFrameProfileSection.h b/libkdchart/KDFrameProfileSection.h
index 48f70bb..9fe38ad 100644
--- a/libkdchart/KDFrameProfileSection.h
+++ b/libkdchart/KDFrameProfileSection.h
@@ -104,7 +104,7 @@ public:
/**
- Profile Curvature Mode: specifying the shape of a frame profile section.
+ Profile Curvature Mode: specifying the tqshape of a frame profile section.
(curvature setting will be ignored for \c DirPlain profiles)
\li \c CvtFlat looking like a evenly sloping surface.
diff --git a/libkdchart/KDXMLTools.h b/libkdchart/KDXMLTools.h
index b68f521..4ebe687 100644
--- a/libkdchart/KDXMLTools.h
+++ b/libkdchart/KDXMLTools.h
@@ -36,7 +36,7 @@
#include <tqdom.h>
#include <tqstring.h>
#include <tqcolor.h>
-#include <brush.h>
+#include <tqbrush.h>
#include <tqsize.h>
#include <tqrect.h>
#include <tqfont.h>
diff --git a/libkdchart/KDChartPainter.cpp b/libkdchart/KDChartPainter.cpp
index 849d2b2..156d5d8 100644
--- a/libkdchart/KDChartPainter.cpp
+++ b/libkdchart/KDChartPainter.cpp
@@ -103,7 +103,7 @@ _legendTitleWidth( 0 ),
_legendTitleMetricsHeight( 0 )
{
// This constructor intentionally left blank so far; we cannot setup the
// geometry yet since we do not know the size of the painter.
}
/**
@@ -657,7 +657,7 @@ void KDChartPainter::paintDataValues( TQPainter* painter,
}
if ( rotation ) {
- anchor = painter->worldMatrix().map( anchor );
+ anchor = painter->tqworldMatrix().map( anchor );
// Temporary solution for fixing the data labels size
// bug when in TQPrinter::HighResolution mode:
@@ -707,7 +707,7 @@ void KDChartPainter::paintDataValues( TQPainter* painter,
true,
true,
5 );
- //anchor = painter->worldMatrix().map( anchor );
+ //anchor = painter->tqworldMatrix().map( anchor );
if( allowOverlapping ) {
drawThisOne = true;
@@ -850,7 +850,7 @@ void KDChartPainter::paintDataValues( TQPainter* painter,
/*
NOTE: The following will be REMOVED again once
-the layout policy feature is implemented !!!
+the tqlayout policy feature is implemented !!!
*/
TQRect textRect( region->pTextRegion->boundingRect() );
@@ -979,7 +979,7 @@ TQPoint KDChartPainter::calculateAnchor( const KDChartCustomBox & box,
// Rule:
//
// A box may be aligned to another box (and the 2nd box may again be
- // aligned to a 3rd box and so on) but NO CIRCULAR alignment is allowed.
+ // aligned to a 3rd box and so on) but NO CIRCULAR tqalignment is allowed.
//
if( !box.anchorBeingCalculated() ) {
@@ -1650,7 +1650,7 @@ void KDChartPainter::paintHeaderFooter( TQPainter* painter,
params()->headerFooterFontRelSize( iHdFt ) * averageValueP1000 ) );
painter->setPen( params()->headerFooterColor( iHdFt ) );
painter->setFont( actFont );
- // Note: The alignment flags used here match the rect calculation
+ // Note: The tqalignment flags used here match the rect calculation
// done in KDChartPainter::setupGeometry().
// AlignTop is done to ensure that the hd/ft texts of the same
// group (e.g. Hd2L and Hd2 and Hd2R) have the same baselines.
@@ -2063,7 +2063,7 @@ void KDChartPainter::calculateAllAxesRects(
int nAxesBottom = TQMAX( nAxesBottom0 + nAxesBottomADD, nMinDistance );
- // for micro alignment with the X axis, we adjust the Y axis - but not for Area Charts:
+ // for micro tqalignment with the X axis, we adjust the Y axis - but not for Area Charts:
// otherwise the areas drawn would overwrite the Y axis line.
int nAxesLeft = TQMAX( nAxesLeft0 + nAxesLeftADD, nMinDistance )
- (bIsAreaChart ? 0 : 1);
@@ -2143,10 +2143,10 @@ void KDChartPainter::calculateAllAxesRects(
/**
This method will be called whenever any parameters that affect
- geometry have been changed. It will compute the appropriate
+ tqgeometry have been changed. It will compute the appropriate
positions for the various parts of the chart (legend, axes, data
area etc.). The implementation in KDChartPainter computes a
- standard geometry that should be suitable for most chart
+ standard tqgeometry that should be suitable for most chart
types. Subclasses can provide their own implementations.
\param data the data that will be displayed as a chart
@@ -2158,7 +2158,7 @@ void KDChartPainter::setupGeometry( TQPainter* painter,
const TQRect& drawRect )
{
//qDebug("INVOKING: KDChartPainter::setupGeometry()");
- // avoid recursion from repaint() being called due to params() changed signals...
+ // avoid recursion from tqrepaint() being called due to params() changed signals...
const bool oldBlockSignalsState = params()->signalsBlocked();
const_cast < KDChartParams* > ( params() )->blockSignals( true );
@@ -103,7 +103,7 @@ _legendTitleWidth( 0 ),
{
// This constructor intentionally left blank so far; we cannot setup the
- // geometry yet since we do not know the size of the painter.
+ // tqgeometry yet since we do not know the size of the painter.
}
/**
diff --git a/libkdchart/KDChartParams.cpp b/libkdchart/KDChartParams.cpp
index e59443f..aac8928 100644
--- a/libkdchart/KDChartParams.cpp
+++ b/libkdchart/KDChartParams.cpp
@@ -707,7 +707,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
break;
++i;
}while( properties(id, propSet) );
// retrieve marker alignment
propSet.deepCopy( &startSet ); i=0;
do{
if( propSet.hasOwnMarkerAlign( id, markerAlign ) ){
@@ -750,7 +750,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// extra lines:
// retrieve alignment of extra lines
propSet.deepCopy( &startSet ); i=0;
do{
if( propSet.hasOwnExtraLinesAlign( id, extraLinesAlign ) ){
@@ -813,7 +813,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// markers at the ends of the extra lines:
// retrieve marker alignment
propSet.deepCopy( &startSet ); i=0;
do{
if( propSet.hasOwnExtraMarkersAlign( id, extraMarkersAlign ) ){
@@ -976,7 +976,7 @@ aligned to.
This must be a reasonable combination of TQt::AlignmentFlags.
\param negativeDeltaX The X distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>alignment point</b>
+ positivePosition, resp.) -- and the internal <b>tqalignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -987,7 +987,7 @@ size of the chart and the specification made via parameter \c size.
\param negativeDeltaY The Y distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>alignment point</b>
+ positivePosition, resp.) -- and the internal <b>tqalignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -1002,7 +1002,7 @@ special values that you might find usefull for Pie charts or for
Ring charts: \c KDCHART_SAGGITAL_ROTATION and \c
KDCHART_TANGENTIAL_ROTATION both leading to individual
calculation of appropriate rotation for each data value. Rotation
-will be performed around the internal <b>alignment point</b> of the
+will be performed around the internal <b>tqalignment point</b> of the
text -- specified by \c negativeAlign (or \c positiveAlign, resp.).
The following parameters apply to values greater than zero or equal zero:
@@ -1013,7 +1013,7 @@ aligned to.
This must be a reasonable combination of TQt::AlignmentFlags.
\param negativeDeltaX The X distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>alignment point</b>
+ positivePosition, resp.) -- and the internal <b>tqalignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -1023,7 +1023,7 @@ delta value are calculated dynamically before painting based on the
size of the chart and the specification made via parameter \c size.
\param positiveDeltaY The Y distance between the <b>anchor
point</b> -- specified by \c negativePosition (or \c
- positivePosition, resp.) -- and the internal <b>alignment point</b>
+ positivePosition, resp.) -- and the internal <b>tqalignment point</b>
of the text -- specified by \c negativeAlign (or \c positiveAlign,
resp.). <b>Note: </b> For better compatibility to the dynamic font
size this parameter is interpreted as being a per-cent value of the
@@ -1038,7 +1038,7 @@ special values that you might find usefull for Pie charts or for
Ring charts: \c KDCHART_SAGGITAL_ROTATION and \c
KDCHART_TANGENTIAL_ROTATION both leading to individual
calculation of appropriate rotation for each data value. Rotation
-will be performed around the internal <b>alignment point</b> of the
+will be performed around the internal <b>tqalignment point</b> of the
text -- specified by \c negativeAlign (or \c positiveAlign, resp.).
\param layoutPolicy The way to handle too narrow space conflicts:
@@ -1872,10 +1872,10 @@ TQString KDChartParams::dataRegionFrameAreaName( uint dataRow,
uint data3rd )
{
return TQString( "%1/%2/%3/%4" )
- .arg( KDChartEnums::AreaChartDataRegion, 5 )
- .arg( dataRow, 5 )
- .arg( dataCol, 5 )
- .arg( data3rd, 5 );
+ .tqarg( KDChartEnums::AreaChartDataRegion, 5 )
+ .tqarg( dataRow, 5 )
+ .tqarg( dataCol, 5 )
+ .tqarg( data3rd, 5 );
}
@@ -2609,7 +2609,7 @@ const KDChartParams::KDChartFrameSettings* KDChartParams::frameSettings( uint ar
{
if( pIterIdx )
*pIterIdx = 0;
- const TQString key( TQString( "%1/-----/-----/-----" ).arg( area, 5 ) );
+ const TQString key( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ) );
KDChartFrameSettings* it = _areaDict.find( key );
bFound = ( it != 0 );
if( bFound )
@@ -2643,7 +2643,7 @@ const KDChartParams::KDChartFrameSettings* KDChartParams::frameSettings( uint ar
*/
bool KDChartParams::removeFrame( uint area )
{
- return _areaDict.remove( TQString( "%1/-----/-----/-----" ).arg( area, 5 ) );
+ return _areaDict.remove( TQString( "%1/-----/-----/-----" ).tqarg( area, 5 ) );
}
@@ -3807,9 +3807,9 @@ int KDChartParams::dataValuesRotation( uint chart, bool negative ) const
a data text covers a neighboring data text (or a neighboring data
area, resp.).
- \note A layout policy different from LayoutJustOverwrite from does
+ \note A tqlayout policy different from LayoutJustOverwrite from does
not mean that this policy is followed in any case. Rather than
- giving up when the selected policy does not result in a good layout
+ giving up when the selected policy does not result in a good tqlayout
the program will automatically try the next policy: if
LayoutPolicyRotate did not succeed LayoutPolicyShiftVertically will
be tried, if this did not succeed either
@@ -4617,7 +4617,7 @@ void KDChartParams::setThreeDBarAngle( uint angle )
point. Only used if chartType() == Line and if threeDLines() ==
false. The default is not to draw markers.
- \note Use the setLineMarkerStyle function to specify the shape
+ \note Use the setLineMarkerStyle function to specify the tqshape
of the markers, use the setLineWidth function to set the
width of the lines connecting the markers (or to surpress
drawing of such lines, resp.)
@@ -7487,7 +7487,7 @@ void KDChartParams::setAxisParams( uint n,
You might want to use those sections to show some marginal information
like department name, print date, page number... <br>
<b>Note:</b> Those headers <b>share the same area</b> so make sure to
- specify propper horizontal alignment for each section when using more than
+ specify propper horizontal tqalignment for each section when using more than
one of them. By default \c HdFtPosHeader0 has centered alignement,
\c HdFtPosHeader0L is aligned to the left and \c HdFtPosHeader0R to the
right side. All of them are vertically aligned to the bottom, you may
@@ -7504,7 +7504,7 @@ void KDChartParams::setAxisParams( uint n,
You could use this headers to show the main information such as project name,
chart title or period of time (e.g. census year). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding alignment mentioned above apply also to these three
+ restrictions regarding tqalignment mentioned above apply also to these three
sections.
\li Up to three <b>additional headers</b> ( \c HdFtPosHeader2 , \c
@@ -7513,7 +7513,7 @@ void KDChartParams::setAxisParams( uint n,
This headers could show additional information such as project phase, chart
sub-title or sub-period of time (e.g. census quarter-year). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding alignment mentioned above apply also to these three
+ restrictions regarding tqalignment mentioned above apply also to these three
sections.
<p>
@@ -7524,7 +7524,7 @@ void KDChartParams::setAxisParams( uint n,
You might want to use these footers instead of (or additional to) the
main header(s) for showing the main information... <br>
Like their header-counterparts they share the same part of the printable area
- so the restrictions regarding alignment mentioned above apply also to these
+ so the restrictions regarding tqalignment mentioned above apply also to these
three sections.
\li Up to three <b>additional footers</b> ( \c HdFtPosFooter2 , \c
@@ -7533,7 +7533,7 @@ void KDChartParams::setAxisParams( uint n,
This footers could show additional information instead of (or additional to)
the additional header(s). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding alignment mentioned above apply also to these three
+ restrictions regarding tqalignment mentioned above apply also to these three
sections.
\li Up to three <b>trailing footers</b> ( \c HdFtPosFooter0 , \c
@@ -7542,7 +7542,7 @@ void KDChartParams::setAxisParams( uint n,
You might want to use those sections to show some marginal information
instead of (or additional to) the leading header(s). <br>
Like their counterparts they share the same part of the printable area so the
- restrictions regarding alignment mentioned above apply also to these three
+ restrictions regarding tqalignment mentioned above apply also to these three
sections.
\note The names \c HdFtPosHeader or \c HdFtPosFooter are the basic names also returned by \c basicAxisPos.
@@ -707,7 +707,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
}while( properties(id, propSet) );
- // retrieve marker alignment
+ // retrieve marker tqalignment
propSet.deepCopy( &startSet ); i=0;
do{
@@ -750,7 +750,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// extra lines:
- // retrieve alignment of extra lines
+ // retrieve tqalignment of extra lines
propSet.deepCopy( &startSet ); i=0;
do{
@@ -813,7 +813,7 @@ bool KDChartParams::calculateProperties( int startId, KDChartPropertySet& rSet )
// markers at the ends of the extra lines:
- // retrieve marker alignment
+ // retrieve marker tqalignment
propSet.deepCopy( &startSet ); i=0;
do{